.. image:: media/image.png
   :width: 200

delorean
==========================

A library to convert markup documents into tree data structures and
vice versa. There is greater functionality available to modify, prune,
add and delete parts of documents when there are in the MarkdownTree
structure.

The full list of features can be found in FEATURES.md or in the documentation.

Install
-------

Install via pip

.. code:: bash

   pip install pydelorean

You can find the library page here `here <nil>`__

Quick Usage Guide
-----------------

Check back later for this section.

.. [[ chikin.md ]]

.. .. code:: markdown

..    # Chikin Tales

..    Once there was a chikin.

..    ## Chapter 1 : Chikin Fly

..    Chickens don't fly. They do only the following:

..    - waddle
..    - plop 


..    ### Waddling

..    A waddle is what these birds do.

..    ## Chapter 2 : Chikin Scream

..    ### Plopping

..    Plopping involves three steps:

..    1. squawk
..    2. plop
..    3. repeat, unless ordered to squat

.. .. code:: text

..                   Chikin Tales
..                  /     \       \
..                 /       \       \ 
..           (Once th..)    |       \
..                          |        \
..                      Chapter 1     \
..                      /     |     Chapter 2   
..                     /      |         |
..           (Chickens do..)  |       Plopping
..                            |         |
..                         Waddling   (Plopping...)
..                            |
..                        (A waddle...)

For a usage guide, access the `samples/` directory or check out the
documentation page here - [nil](nil)

Features
--------

Some of the features of this library are:

Refer to the FEATURES.md file for more information or you can visit the 
documentation page here - [nil](nil)

License
-------

This project is licensed under the Apache 2.0 License. A copy of the license 
can be found in the LICENSE file.